@@ -29,18 +29,14 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <assert.h>
+#include <ctype.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
 
-#if _WIN32 || __CYGWIN__
-#define PRIu64 "I64d"
-#else
-#include <inttypes.h>
-#endif
-
+#include <yara/globals.h>
 #include <yara/mem.h>
 #include <yara/error.h>
 #include <yara/object.h>
@@ -84,7 +80,7 @@ int yr_object_create(
       object_size = sizeof(YR_OBJECT_FUNCTION);
       break;
     default:
-      assert(FALSE);
+      assert(false);
   }
 
   obj = (YR_OBJECT*) yr_malloc(object_size);
@@ -92,6 +88,7 @@ int yr_object_create(
   if (obj == NULL)
     return ERROR_INSUFFICIENT_MEMORY;
 
+  obj->canary = yr_canary;
   obj->type = type;
   obj->identifier = yr_strdup(identifier);
   obj->parent = parent;
@@ -121,7 +118,7 @@ int yr_object_create(
       break;
     case OBJECT_TYPE_FUNCTION:
       object_as_function(obj)->return_obj = NULL;
-      for (i = 0; i < MAX_OVERLOADED_FUNCTIONS; i++)
+      for (i = 0; i < YR_MAX_OVERLOADED_FUNCTIONS; i++)
       {
         object_as_function(obj)->prototypes[i].arguments_fmt = NULL;
         object_as_function(obj)->prototypes[i].code = NULL;
@@ -241,7 +238,7 @@ int yr_object_function_create(
     f = object_as_function(o);
   }
 
-  for (i = 0; i < MAX_OVERLOADED_FUNCTIONS; i++)
+  for (i = 0; i < YR_MAX_OVERLOADED_FUNCTIONS; i++)
   {
     if (f->prototypes[i].arguments_fmt == NULL)
     {
@@ -284,7 +281,7 @@ int yr_object_from_external_variable(
       break;
 
     default:
-      assert(FALSE);
+      assert(false);
   }
 
   result = yr_object_create(
@@ -299,16 +296,16 @@ int yr_object_from_external_variable(
     {
       case EXTERNAL_VARIABLE_TYPE_INTEGER:
       case EXTERNAL_VARIABLE_TYPE_BOOLEAN:
-        yr_object_set_integer(external->value.i, obj, NULL);
+        result = yr_object_set_integer(external->value.i, obj, NULL);
         break;
 
       case EXTERNAL_VARIABLE_TYPE_FLOAT:
-        yr_object_set_float(external->value.f, obj, NULL);
+        result = yr_object_set_float(external->value.f, obj, NULL);
         break;
 
       case EXTERNAL_VARIABLE_TYPE_STRING:
       case EXTERNAL_VARIABLE_TYPE_MALLOC_STRING:
-        yr_object_set_string(
+        result = yr_object_set_string(
             external->value.s, strlen(external->value.s), obj, NULL);
         break;
     }
@@ -422,7 +419,7 @@ YR_OBJECT* yr_object_lookup_field(
 }
 
 
-YR_OBJECT* _yr_object_lookup(
+static YR_OBJECT* _yr_object_lookup(
     YR_OBJECT* object,
     int flags,
     const char* pattern,
@@ -442,7 +439,7 @@ YR_OBJECT* _yr_object_lookup(
   {
     i = 0;
 
-    while(*p != '\0' && *p != '.' && *p != '[' && i < sizeof(str) - 1)
+    while (*p != '\0' && *p != '.' && *p != '[' && i < sizeof(str) - 1)
     {
       str[i++] = *p++;
     }
@@ -487,7 +484,7 @@ YR_OBJECT* _yr_object_lookup(
         i = 0;
         p++;              // skip the opening quotation mark
 
-        while (*p != '"' && *p != '\0' && i < sizeof(str))
+        while (*p != '"' && *p != '\0' && i < sizeof(str) - 1)
           str[i++] = *p++;
 
         str[i] = '\0';
@@ -593,7 +590,7 @@ int yr_object_copy(
               &object_as_function(copy)->return_obj),
           yr_object_destroy(copy));
 
-      for (i = 0; i < MAX_OVERLOADED_FUNCTIONS; i++)
+      for (i = 0; i < YR_MAX_OVERLOADED_FUNCTIONS; i++)
         object_as_function(copy)->prototypes[i] = \
             object_as_function(object)->prototypes[i];
 
@@ -640,7 +637,7 @@ int yr_object_copy(
       break;
 
     default:
-      assert(FALSE);
+      assert(false);
 
   }
 
@@ -725,7 +722,10 @@ int yr_object_array_set_item(
 
   if (array->items == NULL)
   {
-    count = yr_max(64, (index + 1) * 2);
+    count = 64;
+
+    while (count <= index)
+      count *= 2;
 
     array->items = (YR_ARRAY_ITEMS*) yr_malloc(
         sizeof(YR_ARRAY_ITEMS) + count * sizeof(YR_OBJECT*));
@@ -740,6 +740,10 @@ int yr_object_array_set_item(
   else if (index >= array->items->count)
   {
     count = array->items->count * 2;
+
+    while (count <= index)
+      count *= 2;
+
     array->items = (YR_ARRAY_ITEMS*) yr_realloc(
         array->items,
         sizeof(YR_ARRAY_ITEMS) + count * sizeof(YR_OBJECT*));
@@ -855,7 +859,7 @@ int yr_object_dict_set_item(
 }
 
 
-int yr_object_has_undefined_value(
+bool yr_object_has_undefined_value(
     YR_OBJECT* object,
     const char* field,
     ...)
@@ -873,7 +877,7 @@ int yr_object_has_undefined_value(
   va_end(args);
 
   if (field_obj == NULL)
-    return TRUE;
+    return true;
 
   switch(field_obj->type)
   {
@@ -885,7 +889,7 @@ int yr_object_has_undefined_value(
       return field_obj->value.i == UNDEFINED;
   }
 
-  return FALSE;
+  return false;
 }
 
 
@@ -988,7 +992,14 @@ int yr_object_set_integer(
 
   va_end(args);
 
-  assert(integer_obj != NULL);
+  if (integer_obj == NULL)
+  {
+    if (field != NULL)
+      return ERROR_INSUFFICIENT_MEMORY;
+    else
+      return ERROR_INVALID_ARGUMENT;
+  }
+
   assert(integer_obj->type == OBJECT_TYPE_INTEGER);
 
   integer_obj->value.i = value;
@@ -1015,7 +1026,14 @@ int yr_object_set_float(
 
   va_end(args);
 
-  assert(double_obj != NULL);
+  if (double_obj == NULL)
+  {
+    if (field != NULL)
+      return ERROR_INSUFFICIENT_MEMORY;
+    else
+      return ERROR_INVALID_ARGUMENT;
+  }
+
   assert(double_obj->type == OBJECT_TYPE_FLOAT);
 
   double_obj->value.d = value;
@@ -1043,7 +1061,14 @@ int yr_object_set_string(
 
   va_end(args);
 
-  assert(string_obj != NULL);
+  if (string_obj == NULL)
+  {
+    if (field != NULL)
+      return ERROR_INSUFFICIENT_MEMORY;
+    else
+      return ERROR_INVALID_ARGUMENT;
+  }
+
   assert(string_obj->type == OBJECT_TYPE_STRING);
 
   if (string_obj->value.ss != NULL)
