@@ -29,6 +29,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <stdlib.h>
+#include <unistd.h>
 #include <unistd.h>
 #include <signal.h>
 
@@ -1912,6 +1914,16 @@ void test_performance_warnings()
         strings: $a = { 01 ?? ?? 02 } \
         condition: $a }")
 
+  assert_warning(
+      "rule test { \
+        strings: $a = { 00 01 } \
+        condition: $a }")
+
+  assert_warning(
+      "rule test { \
+        strings: $a = { 01 00 } \
+        condition: $a }")
+
   assert_warning(
       "rule test { \
         strings: $a = { 00 00 } \
@@ -1942,17 +1954,27 @@ void test_performance_warnings()
         strings: $a = { FF FF FF FF } \
         condition: $a }")
 
-  assert_no_warning(
+  assert_no_warnings(
+       "rule test { \
+        strings: $a = { 00 01 02 03 } \
+        condition: $a }")
+
+  assert_no_warnings(
        "rule test { \
         strings: $a = { 01 02 03 04 } \
         condition: $a }")
 
-  assert_no_warning(
+  assert_no_warnings(
        "rule test { \
         strings: $a = { 01 02 03 } \
         condition: $a }")
 
-  assert_no_warning(
+  assert_no_warnings(
+       "rule test { \
+        strings: $a = { 20 01 02 } \
+        condition: $a }")
+
+  assert_no_warnings(
        "rule test { \
         strings: $a = { 01 02 } \
         condition: $a }")
@@ -1961,6 +1983,10 @@ void test_performance_warnings()
 
 int main(int argc, char** argv)
 {
+  char *top_srcdir = getenv("TOP_SRCDIR");
+  if (top_srcdir)
+    chdir(top_srcdir);
+
   yr_initialize();
 
   test_boolean_operators();
